@@ -28,14 +28,14 @@
 #include <tqheader.h>
 
 // KDE includes
-#include <kaboutdata.h>
-#include <kaction.h>
-#include <kshortcut.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdeaboutdata.h>
+#include <tdeaction.h>
+#include <tdeshortcut.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 
 // application specific includes
 #include "smb4knetworkbrowser_part.h"
@@ -49,16 +49,16 @@
 #include "../core/smb4kcore.h"
 #include "../core/smb4knetworkitems.h"
 #include "../core/smb4kshare.h"
-#include "../core/smb4kglobal.h"
+#include "../core/smb4tdeglobal.h"
 #include "../core/smb4kpasswordhandler.h"
 #include "../core/smb4ksettings.h"
 #include "../core/smb4kbookmark.h"
 #include "../core/smb4kdefs.h"
 
-using namespace Smb4KGlobal;
+using namespace Smb4TDEGlobal;
 
-KInstance *Smb4KNetworkBrowserPartFactory::m_instance = 0L;
-KAboutData *Smb4KNetworkBrowserPartFactory::m_about = 0L;
+TDEInstance *Smb4KNetworkBrowserPartFactory::m_instance = 0L;
+TDEAboutData *Smb4KNetworkBrowserPartFactory::m_about = 0L;
 
 
 Smb4KNetworkBrowserPart::Smb4KNetworkBrowserPart( TQWidget *parentWidget, const char *widgetName,
@@ -138,35 +138,35 @@ Smb4KNetworkBrowserPart::~Smb4KNetworkBrowserPart()
 
 void Smb4KNetworkBrowserPart::setupActions()
 {
-  KAction *rescan =        new KAction( i18n( "Scan Netwo&rk" ), "reload", KShortcut( CTRL+Key_R ),
+  TDEAction *rescan =        new TDEAction( i18n( "Scan Netwo&rk" ), "reload", TDEShortcut( CTRL+Key_R ),
                                         this, TQT_SLOT( slotRescan() ),
                                         actionCollection(), "rescan_action" );
-  KAction *abort =         new KAction( i18n( "&Abort" ) , "stop", KShortcut( CTRL+Key_A ),
+  TDEAction *abort =         new TDEAction( i18n( "&Abort" ) , "process-stop", TDEShortcut( CTRL+Key_A ),
                                         this, TQT_SLOT( slotAbort() ),
                                         actionCollection(), "abort_action" );
-  KActionSeparator *sep1 = new KActionSeparator( actionCollection(),
+  TDEActionSeparator *sep1 = new TDEActionSeparator( actionCollection(),
                                         "separator_1" );
-  KAction *manual_mount  = new KAction( i18n( "M&ount Manually" ), "connect_creating", KShortcut( CTRL+Key_O ),
+  TDEAction *manual_mount  = new TDEAction( i18n( "M&ount Manually" ), "connect_creating", TDEShortcut( CTRL+Key_O ),
                                         this, TQT_SLOT( slotMountManually() ),
                                         actionCollection(), "mount_manually_action" );
-  KActionSeparator *sep2 = new KActionSeparator( actionCollection(),
+  TDEActionSeparator *sep2 = new TDEActionSeparator( actionCollection(),
                                         "separator_2" );
-  KAction *auth =          new KAction( i18n( "Au&thentication" ), "identity", KShortcut( CTRL+Key_T ),
+  TDEAction *auth =          new TDEAction( i18n( "Au&thentication" ), "identity", TDEShortcut( CTRL+Key_T ),
                                         this, TQT_SLOT( slotAuthentication() ),
                                         actionCollection(), "askpass_action" );
-  KAction *custom =        new KAction( i18n( "&Custom Options" ), "samba", KShortcut( CTRL+Key_C ),
+  TDEAction *custom =        new TDEAction( i18n( "&Custom Options" ), "samba", TDEShortcut( CTRL+Key_C ),
                                         this, TQT_SLOT( slotCustomOptions() ),
                                         actionCollection(), "custom_action" );
-  KAction *bookmark =      new KAction( i18n( "Add &Bookmark" ), "bookmark_add", KShortcut( CTRL+Key_B ),
+  TDEAction *bookmark =      new TDEAction( i18n( "Add &Bookmark" ), "bookmark_add", TDEShortcut( CTRL+Key_B ),
                                         this, TQT_SLOT( slotBookmark() ),
                                         actionCollection(), "bookmark_action" );
-  KAction *preview =       new KAction( i18n( "Pre&view" ), "view_icon", KShortcut( CTRL+Key_V ),
+  TDEAction *preview =       new TDEAction( i18n( "Pre&view" ), "view_icon", TDEShortcut( CTRL+Key_V ),
                                         this, TQT_SLOT( slotPreview() ),
                                         actionCollection(), "preview_action" );
-  KAction *print =         new KAction( i18n( "&Print File" ), "printer1", KShortcut( CTRL+Key_P ),
+  TDEAction *print =         new TDEAction( i18n( "&Print File" ), "printer", TDEShortcut( CTRL+Key_P ),
                                         this, TQT_SLOT( slotPrint() ),
                                         actionCollection(), "print_action" );
-  KAction *mount =         new KAction( i18n( "&Mount" ), "hdd_mount", KShortcut( CTRL+Key_M ),
+  TDEAction *mount =         new TDEAction( i18n( "&Mount" ), "drive-harddisk-mounted", TDEShortcut( CTRL+Key_M ),
                                         this, TQT_SLOT( slotMount() ),
                                         actionCollection(), "mount_action" );
 
@@ -182,7 +182,7 @@ void Smb4KNetworkBrowserPart::setupActions()
   mount->setEnabled( false );
 
   // Plug the actions into the action menu:
-  m_menu = new KActionMenu( this, "NetworkActionMenu" );
+  m_menu = new TDEActionMenu( this, "NetworkActionMenu" );
   m_menu->popupMenu()->insertTitle( SmallIcon( "network" ), i18n( "Network" ), 0 );
   m_menu->insert( rescan, 1 );
   m_menu->insert( abort, 2 );
@@ -200,7 +200,7 @@ void Smb4KNetworkBrowserPart::setupActions()
   // is also needed:
   if ( m_mode == KonqPlugin )
   {
-    KAction *unmount =     new KAction( i18n( "&Unmount" ), "hdd_unmount", KShortcut( CTRL+Key_U ),
+    TDEAction *unmount =     new TDEAction( i18n( "&Unmount" ), "drive-harddisk", TDEShortcut( CTRL+Key_U ),
                                         this, TQT_SLOT( slotUnmount() ),
                                         actionCollection(), "konq_umount_action" );
 
@@ -276,7 +276,7 @@ void Smb4KNetworkBrowserPart::customEvent( TQCustomEvent *e )
     }
     case EVENT_SET_FOCUS:
     {
-      KListView *view = static_cast<KListView *>( m_widget );
+      TDEListView *view = static_cast<TDEListView *>( m_widget );
 
       if ( view->childCount() != 0 )
       {
@@ -1898,14 +1898,14 @@ TQObject *parent, const char *name, const char *, const TQStringList &args )
 }
 
 
-KInstance *Smb4KNetworkBrowserPartFactory::instance()
+TDEInstance *Smb4KNetworkBrowserPartFactory::instance()
 {
   if( !m_instance )
   {
-    m_about = new KAboutData( "smb4knetworkbrowserpart", I18N_NOOP( "Smb4KNetworkBrowserPart" ), "1.0" );
+    m_about = new TDEAboutData( "smb4knetworkbrowserpart", I18N_NOOP( "Smb4KNetworkBrowserPart" ), "1.0" );
     m_about->addAuthor("Alexander Reinholdt", 0, "dustpuppy@users.berlios.de");
-    m_about->setLicense( KAboutData::License_GPL );
-    m_instance = new KInstance( m_about );
+    m_about->setLicense( TDEAboutData::License_GPL );
+    m_instance = new TDEInstance( m_about );
   }
 
   return m_instance;
@@ -1920,7 +1920,7 @@ extern "C"
 {
   void *init_libsmb4knetworkbrowser()
   {
-    KGlobal::locale()->insertCatalogue( "smb4k" );
+    TDEGlobal::locale()->insertCatalogue( "smb4k" );
     return new Smb4KNetworkBrowserPartFactory;
   }
 }
