@@ -37,9 +37,9 @@
 #include <kdebug.h>
 
 // system includes
-#if !defined(__FreeBSD__) && !defined(__solaris__) && !defined(USE_SOLARIS)
+#if !defined(__FreeBSD__) && !defined(__sun)
 #include <sys/statfs.h>
-#elif defined(__solaris__) || defined(USE_SOLARIS)
+#elif defined(__sun)
 #include <sys/statvfs.h>
 #elif defined(__FreeBSD__)
 #include <sys/param.h>
@@ -1046,13 +1046,13 @@ void Smb4KMounter::processMount()
       TQString name = TQString( "//%1/%2" ).arg( m_priv->host() ).arg( m_priv->share() );
 
       // Check file system
-#if !defined(__solaris__)
+#if !defined(__sun)
       struct statfs filesystem;
 #else
       struct statvfs filesystem;
 #endif
 
-#if !defined(__solaris__) && !defined(__irix__)
+#if !defined(__sun) && !defined(__irix__)
       if ( statfs( m_priv->path(), &filesystem ) == -1 )
 #elif defined(__irix__)
       if ( statfs( m_priv->path(), &filesystem, sizeof( filesystem ), 0 ) == -1 )
@@ -1079,7 +1079,7 @@ void Smb4KMounter::processMount()
       }
       else
       {
-#if !defined(__FreeBSD__) && !defined(__solaris__) && !defined(__irix__)
+#if !defined(__FreeBSD__) && !defined(__sun) && !defined(__irix__)
         if ( (uint)filesystem.f_type == 0xFF534D42 /* CIFS */)
         {
           // The user name will be send if no login was specified.
@@ -1095,7 +1095,7 @@ void Smb4KMounter::processMount()
           share =  new Smb4KShare( name, m_priv->path(), "smbfs", (int)getuid(), (int)getgid() );
           m_mounted_shares.append( share );
         }
-#elif defined(__solaris__)
+#elif defined(__sun)
         if ( (uint)filesystem.f_basetype == 0xFF534D42 /* CIFS */)
         {
           // The user name will be send if no login was specified.
